==> neptune_ui-2.1.0.157.jar: com/tandbergtv/neptune/ui/realm/client/alerts/view/AlertTableView.java <==
package com.tandbergtv.neptune.ui.realm.client.alerts.view;

import java.util.ArrayList;
import java.util.Collections;
import java.util.List;

import com.google.gwt.core.client.GWT;
import com.google.gwt.event.dom.client.ClickEvent;
import com.google.gwt.event.dom.client.ClickHandler;
import com.google.gwt.user.client.Window;
import com.google.gwt.user.client.rpc.AsyncCallback;
import com.google.gwt.user.client.ui.Button;
import com.google.gwt.user.client.ui.VerticalPanel;
import com.google.gwt.user.client.ui.Widget;
import com.tandbergtv.neptune.ui.realm.client.alerts.service.IAlertsUIService;
import com.tandbergtv.neptune.ui.realm.client.alerts.service.IAlertsUIServiceAsync;
import com.tandbergtv.neptune.ui.realm.client.alerts.service.UiAlertComparator;
import com.tandbergtv.neptune.ui.realm.client.alerts.service.UiAlertItem;
import com.tandbergtv.neptune.ui.realm.client.alerts.service.UiRecoveryItem;
import com.tandbergtv.neptune.ui.realm.client.alerts.service.UiRecoveryItemType;
import com.tandbergtv.neptune.ui.realm.client.i18n.RealmConstants;
import com.tandbergtv.neptune.widgettoolkit.client.remote.NeptuneAsyncCallback;
import com.tandbergtv.neptune.widgettoolkit.client.widget.basic.ButtonWidget;
import com.tandbergtv.neptune.widgettoolkit.client.widget.basic.ImageWidget;
import com.tandbergtv.neptune.widgettoolkit.client.widget.composite.BusyIndicator;
import com.tandbergtv.neptune.widgettoolkit.client.widget.composite.LazyView;
import com.tandbergtv.neptune.widgettoolkit.client.widget.composite.table.Column;
import com.tandbergtv.neptune.widgettoolkit.client.widget.composite.table.SortOrder;
import com.tandbergtv.neptune.widgettoolkit.client.widget.composite.table.Table;
import com.tandbergtv.neptune.widgettoolkit.client.widget.composite.table.TableConstants;
import com.tandbergtv.neptune.widgettoolkit.client.widget.composite.table.feature.PageFeature;
import com.tandbergtv.neptune.widgettoolkit.client.widget.composite.table.feature.SortFeature;
import com.tandbergtv.neptune.widgettoolkit.client.widget.composite.table.feature.impl.CookieStoreBasedPageFeatureImpl;
import com.tandbergtv.neptune.widgettoolkit.client.widget.composite.table.feature.impl.SortFeatureImpl;
import com.tandbergtv.neptune.widgettoolkit.client.widget.container.VerticalContainer;
import com.tandbergtv.neptune.widgettoolkit.client.widget.style.StyleNames;


public class AlertTableView extends LazyView {
	
	/* Styles / Constants */
	private static final String STYLE_NAME = "realm-UserTableView" ; //"realm-AlertTableView";
	private static final String STYLE_TABLE = STYLE_NAME + "-table";
	private static final String COOKIE_PREFIX = "alertList";	
	
	/* The RPC service */
	private final IAlertsUIServiceAsync service = GWT.create(IAlertsUIService.class);
	
	private RealmConstants constants = GWT.create(RealmConstants.class);
	
	private final BusyIndicator busyIndicator;
	
	private VerticalContainer tableContainer;
	
	private Table<String, AlertItemRecord> alertListTable;
	
	private AlertItemsTableDataProvider tableDataProvider;
	
	private List<UiAlertItem> uiAlertItems;
	
	/**
	 * Constructor
	 */
	public AlertTableView(BusyIndicator busyIndicator) {
		this.busyIndicator = busyIndicator;
		addStyleName(STYLE_NAME);
	}
	
	public void refresh() {
		service.getAlertItems(new NeptuneAsyncCallback<List<UiAlertItem>>() {
			@Override
			public void onNeptuneFailure(Throwable caught) {
				Window.alert("Error getting alert items:" + caught.getMessage());
		        getBusyIndicator().hide();
			}

			@Override
			public void onNeptuneSuccess(List<UiAlertItem> alerts) {
		        getBusyIndicator().hide();
		        uiAlertItems = alerts;
		        refreshTable();
			}		
		});	
	}
	
	List<UiAlertItem> getPagedAlertItems(int startIndex, int pageSize, String sortColumn, SortOrder sortOrder) {
		List<UiAlertItem> alertItems = new ArrayList<UiAlertItem>();
		
		sortAlerts(sortColumn, sortOrder);
		
		int index = startIndex;
		while ((index-startIndex) < pageSize) {
			if (index < this.uiAlertItems.size()) {
				alertItems.add(this.uiAlertItems.get(index));
				index++;
			}	
			else 
				break;
		}
		return alertItems;	
	}
   	
	
	/**
	 * Refresh the view with new state
	 */
	public void refreshTable() {
		ensureWidget();
		/* Initialize and refresh the table */
		initializeTable(new NeptuneAsyncCallback<Void>() {
			@Override
			public void onNeptuneFailure(Throwable caught) {
				Window.alert("initializeTable:" + caught.getMessage());	
			}

			@Override
			public void onNeptuneSuccess(Void result) {
				alertListTable.getPageFeature().setPageNumber(1);
				alertListTable.getPageFeature().setRecordCount(uiAlertItems.size());
				alertListTable.refresh();
			}
		});
	
	}
	
	private void initializeTable(final AsyncCallback<Void> callback) {
		if (alertListTable.isInitialized()) {
			callback.onSuccess(null);
			return;
		}

		alertListTable.initialize(new NeptuneAsyncCallback<Void>() {
			@Override
			public void onNeptuneFailure(Throwable caught) {
				/* Will never happen */
				if (callback != null)
					callback.onFailure(caught);
			}

			@Override
			public void onNeptuneSuccess(Void result) {
				if (callback != null)
					callback.onSuccess(result);
			}
		});
	}
	
	public void reset() {
		if (getWidget() == null)
			return;

		if (alertListTable.isInitialized()) {
			alertListTable.reset();
			alertListTable.showListView();
		}
	}
	
	@Override
	public String getAnchor() {
		if (getWidget() == null)
			return "";

		return alertListTable.getBookmarkFeature().buildAnchor(alertListTable.getTableAnchor());
	}

	
	@Override
	protected void setWidgetAnchor(final String anchor) {
		/* Reset the view */
		reset();

		/* Update the table */
		initializeTable(new NeptuneAsyncCallback<Void>() {
			@Override
			public void onNeptuneFailure(Throwable caught) {
				/* Should not happen */
			}

			@Override
			public void onNeptuneSuccess(Void result) {
				/* The table is refreshed, set the table anchor */
				alertListTable.setAnchor(anchor);
			}
		});
	}

	@Override
	protected Widget createWidget() {
		tableContainer = new VerticalContainer();

		/* Build the data provider and the table widget */
		tableDataProvider = new AlertItemsTableDataProvider(this);
		alertListTable = new Table<String, AlertItemRecord>(tableDataProvider);
		alertListTable.addStyleName(STYLE_TABLE);
		tableContainer.add(alertListTable);
		
		/* Add Fix all recovery options button */
		Button fixAllbutton = new ButtonWidget(constants.fixAllButton());
		fixAllbutton.addClickHandler(new ClickHandler() {
			@Override
			public void onClick(ClickEvent event) {
				handleFixAllButtonClick();				
			}
		});
		fixAllbutton.setStyleName(TableConstants.STYLE_ADD_BUTTON);  /* Added for ECMS   */
		fixAllbutton.addStyleDependentName(StyleNames.DO_BUTTON_STYLE);
		tableContainer.add(fixAllbutton);
		
		/* Add sorting feature */
		SortFeature<String, AlertItemRecord> sortFeature = new SortFeatureImpl<String, AlertItemRecord>(
				tableDataProvider.getColumn(AlertItemsTableDataProvider.TIMESTAMP_COLUMN), SortOrder.DESCENDING);
		
		List<Column<?, AlertItemRecord>> sortableColumns = new ArrayList<Column<?, AlertItemRecord>>();
		sortableColumns.add(tableDataProvider.getColumn(AlertItemsTableDataProvider.TIMESTAMP_COLUMN));
		sortableColumns.add(tableDataProvider.getColumn(AlertItemsTableDataProvider.NAME_COLUMN));
		sortFeature.getSortableColumns().addAll(sortableColumns);
		alertListTable.addSortFeature(sortFeature);
		
		/* Add paging feature */
		PageFeature pageFeature = new CookieStoreBasedPageFeatureImpl(COOKIE_PREFIX);
		pageFeature.setShowTotalCount(true);
		alertListTable.addPageFeature(pageFeature);

		return tableContainer;
	}

	BusyIndicator getBusyIndicator() {
		return busyIndicator;
	}

	public final Table<String, AlertItemRecord> getTable() {
		return alertListTable;
	}
	

	private void sortAlerts(String sortColumn, SortOrder sortOrder) {
		if(sortColumn.equalsIgnoreCase(AlertItemsTableDataProvider.TIMESTAMP_COLUMN) && sortOrder == SortOrder.DESCENDING) {
			Collections.sort(uiAlertItems,
					UiAlertComparator.getComparator(UiAlertComparator.TIME_SORT_DESC, UiAlertComparator.NAME_SORT_ASC));
		}
		else if(sortColumn.equalsIgnoreCase(AlertItemsTableDataProvider.TIMESTAMP_COLUMN) && sortOrder == SortOrder.ASCENDING) {
			Collections.sort(uiAlertItems,
					UiAlertComparator.getComparator(UiAlertComparator.TIME_SORT_ASC, UiAlertComparator.NAME_SORT_ASC));
		}
		else if(sortColumn.equalsIgnoreCase(AlertItemsTableDataProvider.NAME_COLUMN) && sortOrder == SortOrder.ASCENDING) {
			Collections.sort(uiAlertItems,
					UiAlertComparator.getComparator(UiAlertComparator.NAME_SORT_ASC, UiAlertComparator.TIME_SORT_DESC));
		}
		else if(sortColumn.equalsIgnoreCase(AlertItemsTableDataProvider.NAME_COLUMN) && sortOrder == SortOrder.DESCENDING) {
			Collections.sort(uiAlertItems,
					UiAlertComparator.getComparator(UiAlertComparator.NAME_SORT_DESC, UiAlertComparator.TIME_SORT_DESC));
		}
	}
	
	/**
	 * Goes through all of the selected Alert records in order to call the recover service for those selected recovery options.
	 * Will only call the service for those recovery options of the Command type.  Additionally, will update the recovery option
	 * column with the "working" icon.
	 */
	public void handleFixAllButtonClick() {		
		
		if(alertListTable.getSelectedRecords() != null && !alertListTable.getSelectedRecords().isEmpty()) {
						
			final List<UiRecoveryItem> itemsToRecover = new ArrayList<UiRecoveryItem>();
			for(AlertItemRecord record : alertListTable.getSelectedRecords()) {
				if(record.getSelectedRecoveryOption() != null && record.getSelectedRecoveryOption().getType() == UiRecoveryItemType.Command) {
					itemsToRecover.add(record.getSelectedRecoveryOption());

					VerticalPanel panel = record.getRecoveryOptionsPanel();
					panel.clear();
					panel.add(new ImageWidget("/portal/realm/images/gear.png"));
					
					record.setSelectedRecoveryOption(null);
					record.setRecoveryOptionsPanel(null);
				}
			}
			service.recoverAll(itemsToRecover, new RecoverRequestCallback());
		}
	}
	
	private class RecoverRequestCallback extends NeptuneAsyncCallback<UiAlertItem> {
		@Override
		public void onNeptuneFailure(Throwable caught) {
			/* Currently no need to handle */
		}

		@Override
		public void onNeptuneSuccess(UiAlertItem result) {
			/* Currently no need to handle */
		}
	}
}

==> neptune_ui-2.1.0.244.jar: com/tandbergtv/neptune/ui/realm/client/alerts/view/AlertTableView.java <==
package com.tandbergtv.neptune.ui.realm.client.alerts.view;

import java.util.ArrayList;
import java.util.Collections;
import java.util.List;

import com.google.gwt.core.client.GWT;
import com.google.gwt.event.dom.client.ClickEvent;
import com.google.gwt.event.dom.client.ClickHandler;
import com.google.gwt.user.client.Window;
import com.google.gwt.user.client.rpc.AsyncCallback;
import com.google.gwt.user.client.ui.Button;
import com.google.gwt.user.client.ui.VerticalPanel;
import com.google.gwt.user.client.ui.Widget;
import com.tandbergtv.neptune.ui.realm.client.RealmComponentPermissions;
import com.tandbergtv.neptune.ui.realm.client.alerts.service.IAlertsUIService;
import com.tandbergtv.neptune.ui.realm.client.alerts.service.IAlertsUIServiceAsync;
import com.tandbergtv.neptune.ui.realm.client.alerts.service.UiAlertComparator;
import com.tandbergtv.neptune.ui.realm.client.alerts.service.UiAlertItem;
import com.tandbergtv.neptune.ui.realm.client.alerts.service.UiRecoveryItem;
import com.tandbergtv.neptune.ui.realm.client.alerts.service.UiRecoveryItemType;
import com.tandbergtv.neptune.ui.realm.client.i18n.RealmConstants;
import com.tandbergtv.neptune.widgettoolkit.client.application.ClientAuthorizationManager;
import com.tandbergtv.neptune.widgettoolkit.client.remote.NeptuneAsyncCallback;
import com.tandbergtv.neptune.widgettoolkit.client.widget.basic.ButtonWidget;
import com.tandbergtv.neptune.widgettoolkit.client.widget.basic.ImageWidget;
import com.tandbergtv.neptune.widgettoolkit.client.widget.composite.BusyIndicator;
import com.tandbergtv.neptune.widgettoolkit.client.widget.composite.LazyView;
import com.tandbergtv.neptune.widgettoolkit.client.widget.composite.table.Column;
import com.tandbergtv.neptune.widgettoolkit.client.widget.composite.table.SortOrder;
import com.tandbergtv.neptune.widgettoolkit.client.widget.composite.table.Table;
import com.tandbergtv.neptune.widgettoolkit.client.widget.composite.table.TableConstants;
import com.tandbergtv.neptune.widgettoolkit.client.widget.composite.table.feature.PageFeature;
import com.tandbergtv.neptune.widgettoolkit.client.widget.composite.table.feature.SortFeature;
import com.tandbergtv.neptune.widgettoolkit.client.widget.composite.table.feature.impl.CookieStoreBasedPageFeatureImpl;
import com.tandbergtv.neptune.widgettoolkit.client.widget.composite.table.feature.impl.SortFeatureImpl;
import com.tandbergtv.neptune.widgettoolkit.client.widget.container.VerticalContainer;
import com.tandbergtv.neptune.widgettoolkit.client.widget.style.StyleNames;


public class AlertTableView extends LazyView {
	
	/* Styles / Constants */
	private static final String STYLE_NAME = "realm-UserTableView" ; //"realm-AlertTableView";
	private static final String STYLE_TABLE = STYLE_NAME + "-table";
	private static final String COOKIE_PREFIX = "alertList";	
	
	/* The RPC service */
	private final IAlertsUIServiceAsync service = GWT.create(IAlertsUIService.class);
	
	private RealmConstants constants = GWT.create(RealmConstants.class);
	
	private final BusyIndicator busyIndicator;
	
	private VerticalContainer tableContainer;
	
	private Table<String, AlertItemRecord> alertListTable;
	
	private AlertItemsTableDataProvider tableDataProvider;
	
	private List<UiAlertItem> uiAlertItems;
	
	/**
	 * Constructor
	 */
	public AlertTableView(BusyIndicator busyIndicator) {
		this.busyIndicator = busyIndicator;
		addStyleName(STYLE_NAME);
	}
	
	public void refresh() {
		service.getAlertItems(new NeptuneAsyncCallback<List<UiAlertItem>>() {
			@Override
			public void onNeptuneFailure(Throwable caught) {
				Window.alert("Error getting alert items: " + caught.getMessage());
		        getBusyIndicator().hide();
			}

			@Override
			public void onNeptuneSuccess(List<UiAlertItem> alerts) {
		        getBusyIndicator().hide();
		        uiAlertItems = alerts;
		        refreshTable();
			}		
		});	
	}
	
	List<UiAlertItem> getPagedAlertItems(int startIndex, int pageSize, String sortColumn, SortOrder sortOrder) {
		List<UiAlertItem> alertItems = new ArrayList<UiAlertItem>();
		
		sortAlerts(sortColumn, sortOrder);
		
		int index = startIndex;
		while ((index-startIndex) < pageSize) {
			if (index < this.uiAlertItems.size()) {
				alertItems.add(this.uiAlertItems.get(index));
				index++;
			}	
			else 
				break;
		}
		return alertItems;	
	}
   	
	
	/**
	 * Refresh the view with new state
	 */
	public void refreshTable() {
		ensureWidget();
		/* Initialize and refresh the table */
		initializeTable(new NeptuneAsyncCallback<Void>() {
			@Override
			public void onNeptuneFailure(Throwable caught) {
				Window.alert("initializeTable:" + caught.getMessage());	
			}

			@Override
			public void onNeptuneSuccess(Void result) {
				alertListTable.getPageFeature().setPageNumber(1);
				alertListTable.getPageFeature().setRecordCount(uiAlertItems.size());
				alertListTable.refresh();
			}
		});
	
	}
	
	private void initializeTable(final AsyncCallback<Void> callback) {
		if (alertListTable.isInitialized()) {
			callback.onSuccess(null);
			return;
		}

		alertListTable.initialize(new NeptuneAsyncCallback<Void>() {
			@Override
			public void onNeptuneFailure(Throwable caught) {
				/* Will never happen */
				if (callback != null)
					callback.onFailure(caught);
			}

			@Override
			public void onNeptuneSuccess(Void result) {
				if (callback != null)
					callback.onSuccess(result);
			}
		});
	}
	
	public void reset() {
		if (getWidget() == null)
			return;

		if (alertListTable.isInitialized()) {
			alertListTable.reset();
			alertListTable.showListView();
		}
	}
	
	@Override
	public String getAnchor() {
		if (getWidget() == null)
			return "";

		return alertListTable.getBookmarkFeature().buildAnchor(alertListTable.getTableAnchor());
	}

	
	@Override
	protected void setWidgetAnchor(final String anchor) {
		/* Reset the view */
		reset();

		/* Update the table */
		initializeTable(new NeptuneAsyncCallback<Void>() {
			@Override
			public void onNeptuneFailure(Throwable caught) {
				/* Should not happen */
			}

			@Override
			public void onNeptuneSuccess(Void result) {
				/* The table is refreshed, set the table anchor */
				alertListTable.setAnchor(anchor);
			}
		});
	}

	@Override
	protected Widget createWidget() {
		tableContainer = new VerticalContainer();

		/* Build the data provider and the table widget */
		tableDataProvider = new AlertItemsTableDataProvider(this);
		alertListTable = new Table<String, AlertItemRecord>(tableDataProvider);
		alertListTable.addStyleName(STYLE_TABLE);
		tableContainer.add(alertListTable);
		
		/* Add Fix all recovery options button */
		if(canUserPerformRecoveryOption()) {
			Button fixAllbutton = new ButtonWidget(constants.fixAllButton());
			fixAllbutton.addClickHandler(new ClickHandler() {
				@Override
				public void onClick(ClickEvent event) {
					handleFixAllButtonClick();
				}
			});
			fixAllbutton.setStyleName(TableConstants.STYLE_ADD_BUTTON);  /* Added for ECMS   */
			fixAllbutton.addStyleDependentName(StyleNames.DO_BUTTON_STYLE);
			tableContainer.add(fixAllbutton);
		}
		
		/* Add sorting feature */
		SortFeature<String, AlertItemRecord> sortFeature = new SortFeatureImpl<String, AlertItemRecord>(
				tableDataProvider.getColumn(AlertItemsTableDataProvider.TIMESTAMP_COLUMN), SortOrder.DESCENDING);
		
		List<Column<?, AlertItemRecord>> sortableColumns = new ArrayList<Column<?, AlertItemRecord>>();
		sortableColumns.add(tableDataProvider.getColumn(AlertItemsTableDataProvider.TIMESTAMP_COLUMN));
		sortableColumns.add(tableDataProvider.getColumn(AlertItemsTableDataProvider.NAME_COLUMN));
		sortFeature.getSortableColumns().addAll(sortableColumns);
		alertListTable.addSortFeature(sortFeature);
		
		/* Add paging feature */
		PageFeature pageFeature = new CookieStoreBasedPageFeatureImpl(COOKIE_PREFIX);
		pageFeature.setShowTotalCount(true);
		alertListTable.addPageFeature(pageFeature);

		return tableContainer;
	}

	BusyIndicator getBusyIndicator() {
		return busyIndicator;
	}

	public final Table<String, AlertItemRecord> getTable() {
		return alertListTable;
	}
	
	boolean canUserPerformRecoveryOption() {
		return ClientAuthorizationManager.isAuthorized(RealmComponentPermissions.ACTION_ITEMS_FIX);
	}	

	private void sortAlerts(String sortColumn, SortOrder sortOrder) {
		if(sortColumn.equalsIgnoreCase(AlertItemsTableDataProvider.TIMESTAMP_COLUMN) && sortOrder == SortOrder.DESCENDING) {
			Collections.sort(uiAlertItems,
					UiAlertComparator.getComparator(UiAlertComparator.TIME_SORT_DESC, UiAlertComparator.NAME_SORT_ASC));
		}
		else if(sortColumn.equalsIgnoreCase(AlertItemsTableDataProvider.TIMESTAMP_COLUMN) && sortOrder == SortOrder.ASCENDING) {
			Collections.sort(uiAlertItems,
					UiAlertComparator.getComparator(UiAlertComparator.TIME_SORT_ASC, UiAlertComparator.NAME_SORT_ASC));
		}
		else if(sortColumn.equalsIgnoreCase(AlertItemsTableDataProvider.NAME_COLUMN) && sortOrder == SortOrder.ASCENDING) {
			Collections.sort(uiAlertItems,
					UiAlertComparator.getComparator(UiAlertComparator.NAME_SORT_ASC, UiAlertComparator.TIME_SORT_DESC));
		}
		else if(sortColumn.equalsIgnoreCase(AlertItemsTableDataProvider.NAME_COLUMN) && sortOrder == SortOrder.DESCENDING) {
			Collections.sort(uiAlertItems,
					UiAlertComparator.getComparator(UiAlertComparator.NAME_SORT_DESC, UiAlertComparator.TIME_SORT_DESC));
		}
	}
	
	/**
	 * Goes through all of the selected Alert records in order to call the recover service for those selected recovery options.
	 * Will only call the service for those recovery options of the Command type.  Additionally, will update the recovery option
	 * column with the "working" icon.
	 */
	public void handleFixAllButtonClick() {		
		if(canUserPerformRecoveryOption()
				&& alertListTable.getSelectedRecords() != null && !alertListTable.getSelectedRecords().isEmpty()) {
						
			final List<UiRecoveryItem> itemsToRecover = new ArrayList<UiRecoveryItem>();
			for(AlertItemRecord record : alertListTable.getSelectedRecords()) {
				if(record.getSelectedRecoveryOption() != null && record.getSelectedRecoveryOption().getType() == UiRecoveryItemType.Command) {
					itemsToRecover.add(record.getSelectedRecoveryOption());

					VerticalPanel panel = record.getRecoveryOptionsPanel();
					panel.clear();
					panel.add(new ImageWidget("/portal/realm/images/gear.png"));
					
					record.setSelectedRecoveryOption(null);
					record.setRecoveryOptionsPanel(null);
				}
			}
			service.recoverAll(itemsToRecover, new RecoverRequestCallback());
		}
	}
	
	private class RecoverRequestCallback extends NeptuneAsyncCallback<UiAlertItem> {
		@Override
		public void onNeptuneFailure(Throwable caught) {
			/* Currently no need to handle */
		}

		@Override
		public void onNeptuneSuccess(UiAlertItem result) {
			/* Currently no need to handle */
		}
	}
}
